<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * This file give completion datas to get and display completion infos.
 *
 * @package    format_iena
 * @copyright  2018 Softia/Université lorraine
 * @author     Thomas Fradet
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace format_iena\entity;

class course_format_iena_completion {

    /**
     * Get completion by sections
     * @param array $sectionnames
     * @param array $idsection
     * @return type
     */
    public static function get_completion_by_sections($arraySections) {

        global $COURSE, $USER, $DB, $CFG;

        $completion = new \completion_info($COURSE);
        if ($completion->is_enabled_for_site() == false
            || $completion->has_activities() == false || $completion->is_enabled() == 0) {
            return false;
        }
        $course = course_get_format($COURSE)->get_course();
        $fastmodinfo = get_fast_modinfo($COURSE->id);
        $modinfoscms = $fastmodinfo->get_cms();
        $sections=[];
       //$hiddenbutavailable = $course->allmodulesbreadcrum == 1;
        $modules = [];
        //Il récupère les modules qui ne sont pas en cours de suppression, qui ont l'achèvement d'activité, qui sont visibles pour l'user, et qui dépend du paramètre "caché mais disponible"
        /*foreach ($modinfoscms as $cm) {
            $module = $completion->get_data($cm, true, $USER->id, $fastmodinfo);
            $module->url = "$CFG->wwwroot/mod/$cm->modname/view.php?id=$cm->id";
            $module->section = $cm->section;
            if ( $cm->deletioninprogress == 0 && $cm->completion != 0 && $cm->uservisible && ($cm->visibleoncoursepage==1 || $hiddenbutavailable)) {
                $module->name = $cm->name;
                $module->url = "$CFG->wwwroot/mod/$cm->modname/view.php?id=$cm->id";
                $modules[] = $module;
            }
        }*/

        $totalcompleted = 0;
        $totalmodules = 0;
        foreach ($arraySections as $singleSection) {
            $section = new \StdClass();
            $section->id = $singleSection->id;
            $section->name = $singleSection->header->name;
            $innermodules = [];
            $innercompleted = 0;
            $modules=self::get_completion_modules($modinfoscms, $USER->id, $course, $completion, $singleSection);
            //$section->completion=$this->get_completion_by_section($section, $modinfoscms, $course, $modules );
            foreach ($modules as $module) {
                //if ($module->section == $singleSection->id) {
                    $mod = new \StdClass();
                    $mod->coursemoduleid = $module->coursemoduleid;
                    $mod->completion = $module->completionstate;
                    $mod->name = $module->name;
                    $mod->url = $module->url;
                    if ($mod->completion == 1 || $mod->completion == 2) {
                        $innercompleted++;
                    }
                    $innermodules[] = $mod;
                //}
            }
            $section->modules = $innermodules;
            if (count($innermodules) == 0) {
                $section->completion = 0;
            } else {
                $section->completion = number_format(100 * $innercompleted / count($innermodules), 0);
            }
            $totalcompleted += $innercompleted;
            $totalmodules += count($innermodules);

            array_push($sections, $section);
        }
        if ($totalmodules == 0) {
            return false;
        }
        $progress = new \StdClass();
        $progress->total = number_format(100 * $totalcompleted / $totalmodules, 0);
        $progress->sections = $sections;
        return $progress;
    }

    /**
     * [get_completion_by_section Retourne la progression pour une section donnée]
     * @param  [section_info] $section 
     * @param  [type] $cms     liste des modules du cours
     * @param  [type] $course  cours
     * @return [float] $progress    pourcentage de complétion pour une section
     */
    public static function get_completion_by_section($section, $cms, $course) {

        global $USER, $DB, $CFG;

        $completion = new \completion_info($course);
        if ($completion->is_enabled_for_site() == false
            || $completion->has_activities() == false || $completion->is_enabled() == 0) {
            return false;
        }

        ///$course = course_get_format($COURSE)->get_course();//
        //$fastmodinfo = get_fast_modinfo($course->id);
        //$modinfoscms = $fastmodinfo->get_cms();

        $modules = []; 
        $modules=self::get_completion_modules($cms, $USER->id, $course, $completion, $section);
    

        
        //Il récupère les modules qui ne sont pas en cours de suppression, qui ont l'achèvement d'activité, qui sont visibles pour l'user, et qui dépend du paramètre "caché mais disponible"
        /*foreach ($cms as $cm) {
            if ($cm->section == $section->id) {
                $module = $completion->get_data($cm, true, $USER->id);
                $module->url = "$CFG->wwwroot/mod/$cm->modname/view.php?id=$cm->id";
                $module->section = $cm->section;
                if ( $cm->deletioninprogress == 0 && $cm->completion != 0 && $cm->uservisible && ($cm->visibleoncoursepage==1 || $hiddenbutavailable)) {
                    $module->name = $cm->name;
                    $module->url = "$CFG->wwwroot/mod/$cm->modname/view.php?id=$cm->id";
                    $modules[] = $module;
                }
            }

        }*/
        

        $totalcompleted = 0;
        $totalmodules = 0;

        $innermodules = [];
        $innercompleted = 0;
        //on récupère les modules qui ont la complétion d'activé
        foreach ($modules as $module) {
            if ($module->completionstate == 1 || $module->completionstate == 2) {
                $innercompleted++;
            }
            $innermodules[] = $module;
        }
        /*if (count($innermodules) == 0) {
            $section->completion = 0;
        } else {
            $section->completion = number_format(100 * $innercompleted / count($innermodules), 0);
        }*/
        $totalcompleted += $innercompleted;
        $totalmodules += count($innermodules);

        if ($totalmodules == 0) {
            return false;
        }

        $progress = number_format(100 * $totalcompleted / $totalmodules, 0);
        //$progress->sections = $sections;
        return $progress;
    }

    public static function get_completion_by_section_old() {

        global $COURSE, $DB, $USER;

        $completion = new \completion_info($COURSE);
        if ($completion->is_enabled_for_site() == false
            || $completion->has_activities() == false
            || $completion->is_enabled() == 0) {
            return false;
        }

        $modinfo = get_fast_modinfo($COURSE->id);

        $sectionsinfos = $modinfo->get_section_info_all();
        $sectionids = [];
        foreach ($sectionsinfos as $section) {
            array_push($sectionids, $section->__get('id') );
        }

        $modules = $DB->get_records_sql('SELECT cmc.id, cmc.coursemoduleid, cmc.userid, cmc.completionstate, cm.section
            FROM  {course_modules_completion} cmc
            INNER JOIN {course_modules} cm ON cm.id = cmc.coursemoduleid
            INNER JOIN {user} u ON u.id = cmc.userid
            INNER JOIN {modules} m ON m.id = cm.module
            WHERE cm.course = ? AND cm.deletioninprogress = 0
            AND cmc.userid = ?
            ORDER BY section, coursemoduleid ASC',
            array($COURSE->id, $USER->id));

        $sections = [];

        foreach ($sectionids as $i => $sectionid) {
            $section = new \StdClass();
            $section->id = $i;
            $innermodules = [];
            $innercompleted = 0;
            foreach ($modules as $module) {
                if ($module->section == $sectionid) {
                    $mod = new \StdClass();
                    $mod->coursemoduleid = $module->coursemoduleid;
                    $mod->completion = $module->completionstate;
                    if ($mod->completion == 1 || $mod->completion == 2) {
                        $innercompleted++;
                    }
                    $innermodules[] = $mod;
                }
            }
            $section->modules = $innermodules;
            if (count($innermodules) == 0) {
                $section->completion = false;
            } else {
                $section->completion = number_format(100 * $innercompleted / count($innermodules), 0);
            }
            array_push($sections, $section);
        }

        return $sections;
    }

    public static function get_completion_modules($cms, $userid, $course, $completion, $section){
        global $CFG;
        $hiddenbutavailable = $course->allmodulesbreadcrum == 1;
        $modules=[];
        foreach ($cms as $cm) {

            if ($cm->section == $section->id) {

                $module = $completion->get_data($cm, true, $userid);
                $module->url = "$CFG->wwwroot/mod/$cm->modname/view.php?id=$cm->id";
                $module->section = $cm->section;
                if ( $cm->deletioninprogress == 0 && $cm->completion != 0 && $cm->uservisible && ($cm->visibleoncoursepage==1 || $hiddenbutavailable)) {
                    $module->name = $cm->name;
                    $module->url = "$CFG->wwwroot/mod/$cm->modname/view.php?id=$cm->id";
                    $modules[] = $module;
                }
            }

        }
        return $modules;
    }

}

