<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/**
 *
 * course_format_iena_section_ressources
 *
 * @package    format_iena
 * @copyright  2018 Softia/Université lorraine
 * @author     vrignaud camille/Thomas Fradet
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

class course_format_iena_section_ressources {
    /** @var int Id of ressource */
    public $id;
    /** @var string name of ressource */
    public $name;
    /** @var string type of ressource */
    public $type;
    /** @var int module id of ressource */
    public $module;
    /** @var string intro of ressource */
    public $description;
    /** @var course_format_iena_section_ressources section */
    public $section;
    /** @var module hide indicator (from table format_iena_settings) */
    public $ressourcehideindic;

    /**
     * @param $idmodule
     * @return mixed
     * @throws dml_exception
     */
    public function get_ressource_hide_indicator($idmodule) {
        global $DB;
        $modulestate = $DB->get_record_sql('SELECT hide
            FROM {format_iena_settings}
            WHERE cmid = ?',
            array($idmodule));
        return $modulestate->hide;
    }

    /**
     * @param $idmodule
     * @return mixed
     * @throws dml_exception
     */
    public function is_followed_ressources($cmids) {
        global $DB;
        $modulestate = $DB->get_records_sql('SELECT hide
            FROM {format_iena_settings}
            WHERE cmid = ?',
            $cmids);
        return $modulestate;
    }

    /**
     * @param $idsection
     * @return array
     * @throws dml_exception
     */
    public function get_ressources_by_id_section($idsection) {
        global $DB;

        $requete = $DB->get_records_sql('SELECT id
            FROM {course_modules}
            WHERE section = ?
            AND deletioninprogress = 0',
            array($idsection));
        $ressources = array();
        $i = 0;
        foreach ($requete as $value) {
            $ressource = new course_format_iena_section_ressources();
            $ressource->get_ressource_by_id($value->id);
            $ressources[$i] = $ressource;
            $i++;
        }

        return $ressources;
    }

    /**
     * @param $idsection
     * @return array
     * @throws dml_exception
     */
    public function get_ressources_completion_on_by_id_section($idsection) {
        global $COURSE, $DB;

        // Format_iena_settings.hide stands for this module is followed by teacher in a section following indicator —
        // this course module is NOT hidden.

        // Visible : disponibility for studient (right to access), visibleoncoursepage : visibility for student
        // (display on course page) ; 1 : true, 0 : false.

        $course = course_get_format($COURSE)->get_course();

        // Search only modules by general course format parameters
        // count only if it is follewed by teacher
        // count even if it is "hidden on course page but available".
        $evenifhiddenbutavailable = $course->allmodulesbreadcrum == 1;

        if ($evenifhiddenbutavailable) {
            $requete = $DB->get_records_sql('SELECT id
                FROM {course_modules}
                WHERE section = ?
                AND deletioninprogress = 0
                AND visible = 1
                AND completion != 0',
                array($idsection));
        } else {
            $requete = $DB->get_records_sql('SELECT id
                FROM {course_modules}
                WHERE section = ?
                AND deletioninprogress = 0
                AND visible = 1
                AND visibleoncoursepage = 1
                AND completion != 0',
                array($idsection));
        }

        $ressources = array();
        $i = 0;
        foreach ($requete as $value) {
            $ressource = new course_format_iena_section_ressources();
            $ressource->get_ressource_by_id($value->id);
            $ressources[$i] = $ressource;
            $i++;
        }

        return $ressources;
    }

    /**
     * @param $idcoursemodules
     * @throws dml_exception
     */
    public function get_ressource_by_id($idcoursemodules) {

        global $DB;
        if ($idcoursemodules) {
            $this->id = $idcoursemodules;
            $requete = $DB->get_record_sql('SELECT *
                FROM {course_modules}
                WHERE id = ?
                AND deletioninprogress = 0',
                array($idcoursemodules));
            $idinstance = $requete->instance;
            $idmodule = $requete->module;
            if ($idmodule) {
                $modules = $DB->get_record_sql('SELECT *
                    FROM {modules}
                    WHERE id = ?',
                    array($idmodule));
            }
            if ($modules->name) {
                $instance = $DB->get_record_sql('SELECT *
                    FROM {' . $modules->name . '}
                    WHERE id = ?',
                    array($idinstance));
            }
            if ($instance->name) {
                $this->name = $instance->name;
            }
            $this->descrition = $instance->intro;
            $this->type = $modules->name;
            $this->module = $modules->id;
            $this->section = new course_format_iena_sections();
            $this->section->get_section_by_id_section($requete->section);
        }
    }

    /**
     * @param $userid
     * @param $courseid
     * @return array
     * @throws dml_exception
     */
    public function get_completions_by_userid($userid, $courseid) {
        global $DB;
        $modulescompletioninfos = $DB->get_records_sql('SELECT cmc.id, cmc.coursemoduleid, cmc.userid, cmc.completionstate
            FROM  {course_modules_completion} cmc
            INNER JOIN {course_modules} cm ON cm.id = cmc.coursemoduleid
            INNER JOIN {user} u ON u.id = cmc.userid
            INNER JOIN {modules} m ON m.id = cm.module
            WHERE cm.course = ?
            AND cm.deletioninprogress = 0
            AND cmc.userid = ?
            ORDER BY section, coursemoduleid ASC',
            array($courseid, $userid));

        return $modulescompletioninfos;
    }

    /**
     * @param $userid
     * @param $courseid
     * @param $moduleid
     * @return mixed
     * @throws dml_exception
     */
    public function get_completions_by_module($userid, $courseid, $moduleid) {
        global $DB, $COURSE;

        $course = course_get_format($COURSE)->get_course();

        $modulescompletioninfos = $DB->get_record_sql('SELECT cmc.id, cmc.coursemoduleid, cmc.userid, cmc.completionstate
            FROM  {course_modules_completion} cmc
            INNER JOIN {course_modules} cm ON cm.id = cmc.coursemoduleid
            INNER JOIN {user} u ON u.id = cmc.userid
            INNER JOIN {modules} m ON m.id = cm.module
            WHERE cm.course = ?
            AND cm.deletioninprogress = 0
            AND cmc.userid = ?
            AND cmc.coursemoduleid = ?
            ORDER BY section, coursemoduleid ASC',
            array($courseid, $userid, $moduleid));

        return $modulescompletioninfos;
    }
}
