// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * format_iena
 *
 * @package    format_iena
 * @category   format
 * @copyright  2018 Softia/Université lorraine
 * @author     vrignaud camille
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

M.course = M.course || {};

M.course.format = M.course.format || {};

M.course.format.get_config = function() {
    return {
        container_node: 'ul',
        container_class: 'buttons',
        section_node: 'li',
        section_class: 'section'
    };
};

M.course.format.swap_sections = function(Y, node1, node2) {
    var CSS = {
        COURSECONTENT: 'course-content',
        SECTIONADDMENUS: 'section_add_menus'
    };
    var sectionlist = Y.Node.all('.' + CSS.COURSECONTENT + ' ' + M.course.format.get_section_selector(Y));
    // Swap the non-ajax menus, noting these are not always present (depends on theme and user prefs).
    if (sectionlist.item(node1).one('.' + CSS.SECTIONADDMENUS)) {
        sectionlist.item(node1).one('.' + CSS.SECTIONADDMENUS).swap(sectionlist.item(node2).one('.' + CSS.SECTIONADDMENUS));
    }
};

M.course.format.process_sections = function(Y, sectionlist, response, sectionfrom, sectionto) {
    var CSS = {
            SECTIONNAME: 'sectionname'
        },
        SELECTORS = {
            SECTIONLEFTSIDE: '.left .section-handle img'
        };
    if (response.action == 'move') {
        if (sectionfrom > sectionto) {
            var temp = sectionto;
            sectionto = sectionfrom;
            sectionfrom = temp;
        }
        var ele, str, stridx, newstr;
        for (var i = sectionfrom; i <= sectionto; i++) {
            var content = Y.Node.create('<span>' + response.sectiontitles[i] + '</span>');
            sectionlist.item(i).all('.' + CSS.SECTIONNAME).setHTML(content);
            ele = sectionlist.item(i).one(SELECTORS.SECTIONLEFTSIDE);
            str = ele.getAttribute('alt');
            stridx = str.lastIndexOf(' ');
            newstr = str.substr(0, stridx + 1) + i;
            ele.setAttribute('alt', newstr);
            ele.setAttribute('title', newstr);
        }
    }
};

(function () {
    $(".iena-description .description-inner").each(function(index){
        if(parseInt($( this ).css('height'))<=144){
            $(this).parent().next().hide();
        }
    })
    //Gère les animations sur les descriptions des sections pour agrandir/rétrecir les infos
    $('.section').find('a[href="#"].voir-plus').on('click', function (e) {
        e.preventDefault();
        this.expand = !this.expand;
        $(this).text(this.expand?"Réduire la description":"Voir la description complète");
        //$(this).closest('.section').find('.small, .big').toggleClass('small big');
        //
     
        if($(this).prev().hasClass('small')){
            $(this).prev().toggleClass('small big');
            var height= $(this).prev().find(".description-inner").css("height");
            $(this).prev().animate({ "max-height": height }, "slow" );

        } 
        else if($(this).prev().hasClass('big')){

            $(this).prev().toggleClass('small big');
            $(this).prev().animate({ "max-height": '144px' }, "slow" );
        }
        else{
            $(this).prev().addClass("big");
            var height= $(this).prev().find(".description-inner").css("height");
            $(this).prev().animate({ "max-height": height }, "slow" );
        }
        
    });
}(jQuery));