<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/**
 *
 * @package    format_iena
 * @copyright  2018 Softia/Université lorraine
 * @author     vrignaud camille
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

define('NO_OUTPUT_BUFFERING', true);
require_once('../../../config.php');
require_once('../../lib.php');

global $COURSE, $DB, $USER;

$courseid = required_param('courseid', PARAM_INT);
$sectionid = required_param('sectionid', PARAM_INT);
$url = new moodle_url('/course/format/iena/param_section.php', array('courseid' => $courseid, 'sectionid' => $sectionid));

$PAGE->set_pagelayout('course');
$PAGE->set_url($url);

$course = $DB->get_record('course', array('id' => $courseid), '*', MUST_EXIST);
require_login($course, false, null);

if (!has_capability('moodle/course:update', $context = context_course::instance($courseid), $USER->id)) {
    $link = $CFG->wwwroot . '/course/view.php?id=' . $courseid;
    header("Location: {$link}");
    exit;
}

if ($_POST) {
    global $DB;
    $datechaine = $_POST["date_iena"]["year"] . "-" . $_POST["date_iena"]["month"] . "-" . $_POST["date_iena"]["day"] . " " .
    $_POST["date_iena"]["hour"] . ":" . $_POST["date_iena"]["minute"] . ":00";
    $dateup = date_create($datechaine);
    $dataiena = new stdClass();
    if (isset($_POST['date_render'])) {
        $datechaine = "";
    }
    $dataiena->date_rendu = $datechaine;
    $dataiena->presence = $_POST['presence'];
    $dataiena->id_section = $sectionid;
    if (isset($_POST['day_same'])) {
        $dataiena->day_same = $_POST['day_same'];
    } else {
        $dataiena->day_same = 0;
    }

    if (isset($_POST['day_before'])) {
        $dataiena->day_before = $_POST['day_before'];
    } else {
        $dataiena->day_before = 0;
    }
    if (isset($_POST['day_after'])) {
        $dataiena->day_after = $_POST['day_after'];
    } else {
        $dataiena->day_after = 0;
    }
    $dataiena->nb_days_before = $_POST['nb_days_before'];
    $dataiena->nb_days_after = $_POST['nb_days_after'];
    // Anciennement, servait à décider si la section était suivie dans les tableau de bord.
    // Aujourd'hui, c'est le suivi d'achèvement d'activité qui est utilisé à la place.
    $dataiena->hide = false;

    $testifsection = $DB->get_record('format_iena', array('id_section' => $sectionid), '*');
    if ($testifsection == false) {
        $DB->insert_record('format_iena', $dataiena, false);
    } else {
        $dataiena->id = $testifsection->id;
        $DB->update_record('format_iena', $dataiena, false);
    }

    $section = $DB->get_record('course_sections', array('id' => $sectionid), '*', MUST_EXIST);
    $data = new stdClass();
    $data->name = $_POST['name'];
    $data->summary = $_POST['summary']['text'];
    $data->summaryformat = $_POST['summary']['format'];
    course_update_section($COURSE, $section, $data);

    $link = $CFG->wwwroot . '/course/view.php?id=' . $courseid;
    header("Location: {$link}");
    exit;
} else {
    $datasection = $DB->get_record('format_iena', array('id_section' => $sectionid), '*');

    $PAGE->set_title($COURSE->fullname);
    $PAGE->set_heading($COURSE->fullname);
    echo $OUTPUT->header();
    require_once("$CFG->libdir/formslib.php");
    require_once('view/view_param_section.php');
    $viewparamsection = new view_param_section();

    echo $viewparamsection->get_content($course, $datasection);

    echo $OUTPUT->footer();
}
